@@ -8,12 +8,23 @@ import kubernetes
 import urllib3
 import yaml
 from openshift.dynamic import DynamicClient
-from openshift.dynamic.exceptions import InternalServerError, NotFoundError
+from openshift.dynamic.exceptions import (
+    InternalServerError,
+    NotFoundError,
+    ServerTimeoutError,
+)
 from urllib3.exceptions import ProtocolError
 
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 
 
+DEFAULT_CLUSTER_RETRY_EXCEPTIONS = {
+    ConnectionAbortedError: [],
+    ConnectionResetError: [],
+    InternalServerError: ["etcdserver: leader changed"],
+    ServerTimeoutError: [],
+}
+
 LOGGER = logging.getLogger(__name__)
 TIMEOUT = 240
 MAX_SUPPORTED_API_VERSION = "v1"
@@ -626,13 +637,12 @@ class Resource(object):
         self.api().replace(body=resource_dict, name=self.name, namespace=self.namespace)
 
     @staticmethod
-    def _retry_etcd_changed(func):
+    def _retry_cluster_exceptions(func):
         sampler = TimeoutSampler(
             wait_timeout=10,
             sleep=1,
             func=func,
-            exceptions=InternalServerError,
-            exceptions_msg="etcdserver: leader changed",
+            exceptions_dict=DEFAULT_CLUSTER_RETRY_EXCEPTIONS,
             print_log=False,
         )
         for sample in sampler:
@@ -661,7 +671,7 @@ class Resource(object):
             except TypeError:
                 yield cls(client=dyn_client, name=_resources.metadata.name)
 
-        return Resource._retry_etcd_changed(func=_get)
+        return Resource._retry_cluster_exceptions(func=_get)
 
     @property
     def instance(self):
@@ -675,7 +685,7 @@ class Resource(object):
         def _instance():
             return self.api().get(name=self.name)
 
-        return self._retry_etcd_changed(func=_instance)
+        return self._retry_cluster_exceptions(func=_instance)
 
     @property
     def labels(self):
